@@ -560,14 +560,6 @@ def info():
 
     
 
-biodata(0)
-print("done1")
-biodata(4)
-print("done2")
-biodata(-4)
-print("done3")
-biodata(12345)
-print("last")
-biodata(-12345)
+
 
 
